@@ -13,7 +13,7 @@ fi
 source simpleburn-burning-suite quiet
 
 
-tempdir="/tmp/simplebur$$"
+tempdir="/tmp/simpleburn$$"
 
 mkdir $tempdir
 cd $tempdir
